@@ -42,14 +42,6 @@
 #' it creates an rds with borders and saves it.
 #' This can be created in advance with \code{redist.prep.polsbypopper}.
 #' @param perim_df A dataframe output from \code{redist.prep.polsbypopper}
-#' @param district_membership Deprecated. Use plans. A numeric vector (if only one map) or matrix with one row
-#' for each precinct and one column for each map. Required.
-#' @param population Deprecated. Use total_pop. A numeric vector with the population for every observation. Is
-#' only necessary when "FryerHolden" is used for measure. Defaults to NULL.
-#' @param adjacency Deprecated. Use adj. A zero-indexed adjacency list. Only used for "EdgesRemoved" and "logSpanningTree".
-#' Created with \code{redist.adjacency} if not supplied and needed. Default is NULL.
-#' @param nloop Deprecated, use draw. A numeric to specify loop number. Defaults to 1 if only one map provided
-#' and the column number if multiple maps given.
 #'
 #' @details This function computes specified compactness scores for a map.  If
 #' there is more than one shape specified for a single district, it combines
@@ -156,26 +148,7 @@ redist.compactness <- function(shp = NULL,
                                measure = c("PolsbyPopper"),
                                total_pop = NULL, adj = NULL, draw = 1,
                                ncores = 1, counties = NULL, planarize = 3857,
-                               ppRcpp, perim_path, perim_df,
-                               district_membership, population, adjacency, nloop){
-
-  if(!missing(district_membership)){
-    plans <- district_membership
-    .Deprecated(new = 'plans', old = 'district_membership')
-  }
-  if(!missing(population)){
-    total_pop <- population
-    .Deprecated(new = 'total_pop', old = 'population')
-  }
-  if(!missing(adjacency)){
-    adj <- adjacency
-    .Deprecated(new = 'adj', old = 'adjacency')
-  }
-  if(!missing(nloop)){
-    draw <- nloop
-    .Deprecated(new = 'draw', old = 'nloop')
-  }
-
+                               ppRcpp, perim_path, perim_df){
   # Check Inputs
   if (is.null(shp) & is.null(adj)) {
     stop('Please provide a shp or adj argument.')
@@ -187,6 +160,13 @@ redist.compactness <- function(shp = NULL,
     } else if (!inherits(shp, 'sf')) {
       stop('Please provide "shp" as a SpatialPolygonsDataFrame or sf object.')
     }
+
+
+    if (isTRUE(st_is_longlat(st_geometry(shp)))) {
+      if (!is.null(st_crs(shp)) & !is.null(planarize) && !isFALSE(planarize)) {
+        shp <- st_transform(shp, planarize)
+      }
+    }
   }
 
   if (inherits(shp, 'redist_map') & missing(adj)) {
@@ -208,13 +188,14 @@ redist.compactness <- function(shp = NULL,
 
 
 
-
-  if (isTRUE(st_is_longlat(st_geometry(shp)))) {
-    if (!requireNamespace("s2", quietly=TRUE))
-      stop("Must install `s2` to use longitude-latitude coordinate projections.")
-
-    if (!is.null(st_crs(shp)) & !is.null(planarize) && !isFALSE(planarize)) {
-      shp <- st_transform(shp, planarize)
+  if(!is.null(shp)){
+    if (isTRUE(st_is_longlat(st_geometry(shp)))) {
+      if (!requireNamespace("s2", quietly=TRUE))
+        stop("Must install `s2` to use longitude-latitude coordinate projections.")
+      
+      if (!is.null(st_crs(shp)) & !is.null(planarize) && !isFALSE(planarize)) {
+        shp <- st_transform(shp, planarize)
+      }
     }
   }
 
@@ -281,7 +262,7 @@ redist.compactness <- function(shp = NULL,
     `%oper%` <- `%do%`
   } else {
     `%oper%` <- `%dopar%`
-    cl <- makeCluster(nc, setup_strategy = 'sequential')
+    cl <- makeCluster(nc, setup_strategy = 'sequential', methods=FALSE)
     registerDoParallel(cl)
     on.exit(stopCluster(cl))
   }
@@ -481,10 +462,10 @@ redist.compactness <- function(shp = NULL,
 #' @export
 #'
 #' @importFrom sf st_buffer st_is_valid st_geometry<- st_touches st_transform
-#' @examples 
+#' @examples
 #' data(fl25)
 #' perim_df <- redist.prep.polsbypopper(shp = fl25)
-#' 
+#'
 redist.prep.polsbypopper <- function(shp, planarize = 3857, perim_path, ncores = 1){
 
   if(missing(shp)){
@@ -509,7 +490,7 @@ redist.prep.polsbypopper <- function(shp, planarize = 3857, perim_path, ncores =
     `%oper%` <- `%do%`
   } else {
     `%oper%` <- `%dopar%`
-    cl <- makeCluster(ncores, setup_strategy = 'sequential')
+    cl <- makeCluster(ncores, setup_strategy = 'sequential', methods=FALSE)
     registerDoParallel(cl)
     on.exit(stopCluster(cl))
   }
