@@ -1,21 +1,20 @@
-#include <Rcpp.h>
-using namespace Rcpp;
+#include "smc_base.h"
 
 // [[Rcpp::export]]
 int closest_adj_pop(IntegerVector adj,
                 int i_dist,
                 NumericVector g_prop){
-  
+
   if(adj.size() == 1){
     return adj[0];
   }
-  
-  // inits 
-  double min_distance = fabs( g_prop(i_dist) - g_prop(adj(0)) ); 
+
+  // inits
+  double min_distance = fabs( g_prop(i_dist) - g_prop(adj(0)) );
   int min_district = adj[0];
   int curr_distance;
-  
-  
+
+
   // loop
   for(int j = 1; j < adj.size(); j++){
     curr_distance = fabs( g_prop(i_dist) - g_prop(adj(j)) );
@@ -24,7 +23,7 @@ int closest_adj_pop(IntegerVector adj,
       min_district = adj[j];
     }
   }
-  
+
   return min_district;
 }
 
