@@ -28,7 +28,7 @@ Rcpp::List make_swaps(Rcpp::List boundary_cc,
 		      Rcpp::NumericVector areas_vec,
 		      arma::mat borderlength_mat,
 		      Rcpp::NumericMatrix ssdmat,
-		      Rcpp::NumericVector county_membership,
+		      Rcpp::IntegerVector county_membership,
 		      double minparity,
 		      double maxparity,
 		      int p,
@@ -37,10 +37,21 @@ Rcpp::List make_swaps(Rcpp::List boundary_cc,
 		      double weight_population,
 		      double weight_compact,
 		      double weight_segregation,
+		      double weight_vra,
 		      double weight_similar,
 		      double weight_countysplit,
+		      double weight_partisan,
+		      double weight_minority,
+		      double weight_hinge,
 		      double ssd_denominator,
-		      std::string compactness_measure);
+		      double tgt_min,
+		      double tgt_other,
+		      Rcpp::IntegerVector rvote,
+		      Rcpp::IntegerVector dvote,
+		      Rcpp::NumericVector minorityprop,
+		      std::string compactness_measure,
+		      std::string partisan_measure,
+		      const Graph &g);
 int mh_decision(double mh_prob);
 Rcpp::List changeBeta(arma::vec betavec,
 		      double beta,
